@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import print_function
-from __future__ import absolute_import
 import os
 import sys
 import time
@@ -15,7 +13,6 @@ from tables import StringCol, IntCol, Int16Col, FloatCol, Float32Col
 from tables.tests import common
 from tables.tests.common import unittest
 from tables.tests.common import PyTablesTestCase as TestCase
-from six.moves import range
 
 
 # Test Record class
@@ -168,20 +165,20 @@ class TreeTestCase(common.TempFileMixin, TestCase):
 
         # This tree ways of get_node usage should return a table instance
         table = self.h5file.get_node("/group0/table1")
-        self.assertTrue(isinstance(table, Table))
+        self.assertIsInstance(table, Table)
         table = self.h5file.get_node("/group0", "table1")
-        self.assertTrue(isinstance(table, Table))
+        self.assertIsInstance(table, Table)
         table = self.h5file.get_node(self.h5file.root.group0, "table1")
-        self.assertTrue(isinstance(table, Table))
+        self.assertIsInstance(table, Table)
 
         # This should return an array instance
         arr = self.h5file.get_node("/group0/var1")
-        self.assertTrue(isinstance(arr, Array))
-        self.assertTrue(isinstance(arr, Leaf))
+        self.assertIsInstance(arr, Array)
+        self.assertIsInstance(arr, Leaf)
 
         # And this a Group
         group = self.h5file.get_node("/group0", "group1", "Group")
-        self.assertTrue(isinstance(group, Group))
+        self.assertIsInstance(group, Group)
 
     def test02_listNodes(self):
         """Checking the File.list_nodes() method"""
@@ -499,6 +496,62 @@ class TreeTestCase(common.TempFileMixin, TestCase):
         if common.verbose:
             print("walk_nodes(pathname, classname) test passed")
 
+    def test05_dir(self):
+        """Checking Group.__dir__"""
+
+        if common.verbose:
+            print('\n', '-=' * 30)
+            print("Running %s.test05_dir..." % self.__class__.__name__)
+
+        self.h5file = tables.open_file(self.h5fname, "r")
+
+        """
+        h5file nodes:
+        '/table0', '/var1', '/var4'
+        '/group0/table1', '/group0/var1', '/group0/var4',
+        '/group0/group1/table2', '/group0/group1/var1', '/group0/group1/var4'
+        """
+        root_dir = dir(self.h5file.root)
+
+        ## Check some regular attributes.
+        #
+        self.assertIn('_v_children', root_dir)
+        self.assertIn('_v_attrs', root_dir)
+        self.assertIn('_g_get_child_group_class', root_dir)
+        self.assertIn('_g_get_child_group_class', root_dir)
+        self.assertIn('_f_close', root_dir)
+
+        ## Check children nodes.
+        #
+        self.assertIn('group0', root_dir)
+        self.assertIn('table0', root_dir)
+        self.assertIn('var1', root_dir)
+        self.assertNotIn('table1', root_dir)
+        self.assertNotIn('table2', root_dir)
+        self.assertSequenceEqual(sorted(set(root_dir)),
+                                 sorted(root_dir))  # Check for no duplicates.
+
+        root_group0_dir = dir(self.h5file.root.group0)
+        self.assertIn('group1', root_group0_dir)
+        self.assertIn('table1', root_group0_dir)
+        self.assertNotIn('table0', root_group0_dir)
+        self.assertNotIn('table2', root_group0_dir)
+        self.assertSequenceEqual(sorted(set(root_group0_dir)),
+                                 sorted(root_group0_dir))
+
+        root_group0_group1_dir = dir(self.h5file.root.group0.group1)
+        self.assertIn('group2', root_group0_group1_dir)
+        self.assertIn('table2', root_group0_group1_dir)
+        self.assertNotIn('table0', root_group0_group1_dir)
+        self.assertNotIn('table1', root_group0_group1_dir)
+        self.assertNotIn('group0', root_group0_group1_dir)
+        self.assertNotIn('group1', root_group0_group1_dir)
+        self.assertSequenceEqual(sorted(set(root_group0_group1_dir)),
+                                 sorted(root_group0_group1_dir))
+
+        if common.verbose:
+            print("Group.__dir__ test passed")
+
 
 class DeepTreeTestCase(common.TempFileMixin, TestCase):
     """Checks for deep hierarchy levels in PyTables trees."""
@@ -555,8 +608,8 @@ class DeepTreeTestCase(common.TempFileMixin, TestCase):
 
                 # Check the contents
                 self.assertEqual(group.array[:], [1, 1])
-                self.assertTrue("array2" in group)
-                self.assertTrue("group2_"+str(depth) in group)
+                self.assertIn("array2", group)
+                self.assertIn("group2_"+str(depth), group)
 
                 # Iterate over the next group
                 group = h5file.get_node(group, 'group' + str(depth))
@@ -868,7 +921,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
 
         for group in self.h5file.walk_groups('/'):
             pathname = group._v_pathname
-            self.assertTrue(pathname not in hidden,
+            self.assertNotIn(pathname, hidden,
                             "Walked across hidden group ``%s``." % pathname)
 
     def test03_walkNodes(self):
@@ -878,7 +931,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
 
         for node in self.h5file.walk_nodes('/'):
             pathname = node._v_pathname
-            self.assertTrue(pathname not in hidden,
+            self.assertNotIn(pathname, hidden,
                             "Walked across hidden node ``%s``." % pathname)
 
     def test04_listNodesVisible(self):
@@ -888,7 +941,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
 
         for node in self.h5file.list_nodes('/g'):
             pathname = node._v_pathname
-            self.assertTrue(pathname not in hidden,
+            self.assertNotIn(pathname, hidden,
                             "Listed hidden node ``%s``." % pathname)
 
     def test04b_listNodesVisible(self):
@@ -898,7 +951,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
 
         for node in self.h5file.iter_nodes('/g'):
             pathname = node._v_pathname
-            self.assertTrue(pathname not in hidden,
+            self.assertNotIn(pathname, hidden,
                             "Listed hidden node ``%s``." % pathname)
 
     def test05_listNodesHidden(self):
@@ -912,7 +965,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
             pathname = node._v_pathname
             if pathname == node_to_find:
                 found_node = True
-            self.assertTrue(pathname in hidden,
+            self.assertIn(pathname, hidden,
                             "Listed hidden node ``%s``." % pathname)
 
         self.assertTrue(found_node,
@@ -929,7 +982,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
             pathname = node._v_pathname
             if pathname == node_to_find:
                 found_node = True
-            self.assertTrue(pathname in hidden,
+            self.assertIn(pathname, hidden,
                             "Listed hidden node ``%s``." % pathname)
 
         self.assertTrue(found_node,
@@ -958,9 +1011,9 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
     def test08_remove(self):
         """Removing a visible group with hidden children."""
 
-        self.assertTrue('/g/_p_a' in self.h5file)
+        self.assertIn('/g/_p_a', self.h5file)
         self.h5file.root.g._f_remove(recursive=True)
-        self.assertFalse('/g/_p_a' in self.h5file)
+        self.assertNotIn('/g/_p_a', self.h5file)
 
 
 class CreateParentsTestCase(common.TempFileMixin, TestCase):
@@ -997,17 +1050,17 @@ class CreateParentsTestCase(common.TempFileMixin, TestCase):
         self.assertRaises(tables.NodeError, self.h5file.move_node,
                           '/group', '/group/foo/bar',
                           createparents=True)
-        self.assertFalse('/group/foo' in self.h5file)
+        self.assertNotIn('/group/foo', self.h5file)
         self.assertRaises(tables.NodeError, self.h5file.copy_node,
                           '/group', '/group/foo/bar',
                           recursive=True, createparents=True)
-        self.assertFalse('/group/foo' in self.h5fname)
+        self.assertNotIn('/group/foo', self.h5fname)
 
     def test02_filters(self):
         """Propagating the filters of created parent groups."""
 
         self.h5file.create_group('/group/foo/bar', 'baz', createparents=True)
-        self.assertTrue('/group/foo/bar/baz' in self.h5file)
+        self.assertIn('/group/foo/bar/baz', self.h5file)
         for group in self.h5file.walk_groups('/group'):
             self.assertEqual(self.filters, group._v_filters)
 
